@@ -9,7 +9,7 @@ import pyconvox
 
 
 def Apps(args,apps,parser):
-    stream = os.popen(f"xovnoc apps")
+    stream = os.system(f"xovnoc apps")
 
 
 def Env(args,apps,parser):
